@@ -2,9 +2,7 @@
 
 # Infoseek.pm
 # Copyright (C) 1998 by Martin Thurn
-# $Id: Infoseek.pm,v 1.9 1998/08/27 17:29:01 johnh Exp $
-
-package WWW::Search::Infoseek;
+# $Id: Infoseek.pm,v 1.11 1998/10/06 00:53:12 johnh Exp $
 
 =head1 NAME
 
@@ -28,7 +26,6 @@ F<http://www.infoseek.com>.
 This class exports no public interface; all interaction should
 be done through L<WWW::Search> objects.
 
-
 =head1 SEE ALSO
 
   L<WWW::Search::Infoseek::Companies>
@@ -37,7 +34,6 @@ be done through L<WWW::Search> objects.
 
 To make new back-ends, see L<WWW::Search>.
 
-
 =head1 HOW DOES IT WORK?
 
 C<native_setup_search> is called (from C<WWW::Search::setup_search>)
@@ -53,54 +49,59 @@ C<{cache}>.  If it finds a ``next'' button in the text,
 it sets C<{_next_url}> to point to the page for the next
 set of results, otherwise it sets it to undef to indicate we''re done.
 
-
 =head1 BUGS
 
 Please tell the author if you find any!
 
-
 =head1 TESTING
 
 This module adheres to the C<WWW::Search> test suite mechanism. 
 
 See C<WWW::Search::Infoseek::Web> for test cases for the default usage.
 
-
 =head1 AUTHOR
 
 C<WWW::Search::Infoseek> is maintained by Martin Thurn
 (MartinThurn@iname.com).
 
-
 =head1 LEGALESE
 
 THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
 WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
 MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
-
 =head1 VERSION HISTORY
 
 If it''s not listed here, then it wasn''t a meaningful nor released revision.
 
+=head2 1.7, 1998-10-05
+
+www.Infoseek.com changed their output format.
+Thanks to Andreas Borchert (borchert@mathematik.uni-ulm.de) for patches.
+
+=head2 1.6, 1998-09-18
+
+Fixed BUG where (apparently) no titles were retrieved.
+
 =head2 1.5
 
-Infoseek changed their output format ever-so-slightly.
+www.Infoseek.com changed their output format ever-so-slightly.
 
 =head2 1.3
 
 First publicly-released version.
 
-
 =cut
 
 #####################################################################
 
+package WWW::Search::Infoseek;
+
 require Exporter;
 @EXPORT = qw();
 @EXPORT_OK = qw();
 @ISA = qw(WWW::Search Exporter);
-$VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
 
 use Carp ();
 use WWW::Search(generic_option);
@@ -112,14 +113,16 @@ sub native_setup_search
   {
   my ($self, $native_query, $rhOptions) = @_;
 
+  # WARNING: www.Infoseek.com returns 25 hits per page no matter what number
+  # you send in the argument list!
   my $DEFAULT_HITS_PER_PAGE = 25;
   # $DEFAULT_HITS_PER_PAGE = 10;  # for debugging
-  # Infoseek does not let you choose the number of hits per page!!!
   $self->{'_hits_per_page'} = $DEFAULT_HITS_PER_PAGE;
 
   $self->{agent_e_mail} = 'MartinThurn@iname.com';
 
-  # Infoseek doesn't like robots: response from server was 403 (Forbidden) Forbidden by robots.txt
+  # www.Infoseek.com doesn't like robots: response from server was 403
+  # (Forbidden) Forbidden by robots.txt
   $self->user_agent(1);
 
   $self->{'_next_to_retrieve'} = 0;
@@ -208,19 +211,19 @@ sub native_retrieve_some
   print STDERR " *   got response\n" if $self->{'_debug'};
   $self->{'_next_url'} = undef;
   # Parse the output
-  my ($START, $HEADER, $HITS, $DESC,$PERCENT,$SIZE,$DATE, $NEXT,$COMP_NEXT, $TRAILER) = qw(ST HE HI DE PE SI DA NE CN TR);
+  my ($START, $HEADER, $HITS, $DESC,$PERCENT,$SIZE,$DATE, $NEXT,$COMP_NEXT, $TRAILER) = qw( ST HE HI DE PE SI DA NE CN TR );
   my $hits_found = 0;
   my $state = $START;
   my $hit;
-  foreach ($self->split_lines($response->content())) 
+  foreach (split(/\n/, $response->content())) 
     {
     next if m/^$/; # short circuit for blank lines
     print STDERR " *   $state ===$_===" if 2 <= $self->{'_debug'};
     if ($state eq $START && 
-        m=Infoseek\sfound\s+([\d,]+)=)
+	m=RESULT.*?\s+of\s+([\d,]+)\s+total results=i) # afb 10/98
       {
       # Actual line of input is:
-      # Infoseek found 25
+      # <b>RESULTS 1 - 25</b>  of 192 total results
       print STDERR "header line\n" if 2 <= $self->{'_debug'};
       my $iCount = $1;
       $iCount =~ s/,//g;
@@ -228,11 +231,13 @@ sub native_retrieve_some
       $state = $HEADER;
       } # we're in START mode, and line has number of results
     elsif ($state eq $START && 
-           m=<b>Articles</b>\s+\d+\s+-\s+\d+\s+of\s+(\d+)=)
+           m=<b>ARTICLES\s+\d+\s+-\s+\d+</b>\s+of\s+([0-9,]+)=)
       {
       # Actual line of input is:
-      # <b>Company Results</b>  51 -  100 of  104
+      # <b>ARTICLES 1 - 25</b>  of 1,239 total articles <p>
       print STDERR "header line\n" if 2 <= $self->{'_debug'};
+      my $iCount = $1;
+      $iCount =~ tr/[^0-9]//;
       $self->approximate_result_count($1);
       $state = $HEADER;
       } # we're in START mode, and line has number of results
@@ -255,10 +260,10 @@ sub native_retrieve_some
       } # we're in HEADER mode, and line talks about (un)grouping results
 
     elsif (($state eq $NEXT || $state eq $COMP_NEXT) &&
-           m@>next(&nbsp;|\s+)\d@)
+           m@>Next(&nbsp;|\s+)\d+@i)
       {
       # Actual line of input is:
-      #    &nbsp;&nbsp;|&nbsp;&nbsp;<a href="/Titles?qt=star+wars+collector&rf=11&st=50&nh=25&rf=11">next&nbsp;25</a>
+      #    &nbsp;&nbsp;|&nbsp;&nbsp;<a href="/Titles?qt=star+wars+collector&rf=11&st=50&nh=25&rf=11">Next&nbsp;25</a>
       print STDERR " found next button\n" if 2 <= $self->{'_debug'};
       # There is a "next" button on this page, therefore there are
       # indeed more results for us to go after next time.
@@ -287,7 +292,7 @@ sub native_retrieve_some
       # There is no next button.
       $state = $HITS;
       }
-    elsif ($state eq $COMP_NEXT && m=^</table>$=)
+    elsif ($state eq $COMP_NEXT && m=^</td></tr></table>$=) # afb 10/98
       {
       print STDERR " no next button (web mode)\n" if 2 <= $self->{'_debug'};
       # There is no next button.
@@ -320,30 +325,31 @@ sub native_retrieve_some
       # <b><a href="http://www.wizardpress.com/68toychst.html">Wizard Press Columns and Departments:Toychest!</a></b><br>
       # Sometimes the </A> is on the next line.
       # Sometimes there is a /r right before the </A>
-      my $sURL = $1;
+      my ($sURL,$sTitle) = ($1,$2);
       if (defined($hit))
         {
         push(@{$self->{cache}}, $hit);
         }
       $hit = new WWW::SearchResult;
-      # hits from Companies database are internal Infoseek links:
+      # hits from Companies database are internal www.Infoseek.com links:
       $sURL = 'http://www.infoseek.com'. $sURL if $sURL =~ m@^/Content@;
       $hit->add_url($sURL);
       $self->{'_num_hits'}++;
       $hits_found++;
-      $hit->title($2);
+      $hit->title($sTitle);
       $state = $DESC;
       }
 
     elsif ($state eq $DESC &&
-           m|^(.*)<br>$|)
+           m|<br>(.*)<br>$|)
       {
       print STDERR "hit description line\n" if 2 <= $self->{'_debug'};
       # Sometimes description is empty
-      $hit->description($1);
+      $hit->description($1) if ref($hit);
       if ($hit->url =~ m/col=NX/)
         {
-        $state = $DATE;
+        # This a NEWS results page
+        $state = $HITS;
         } 
       else
         {
@@ -355,42 +361,42 @@ sub native_retrieve_some
       {
       print STDERR "hit company description line\n" if 2 <= $self->{'_debug'};
       # Sometimes description is empty
-      $hit->description($1);
+      $hit->description($1) if ref($hit);
       $state = $HITS;
       } # line is description
 
-    elsif ($state eq $PERCENT && m=<b>(\d+)\%</b>=)
+    elsif ($state eq $HITS && m=(\d+)\%$=)
       {
       print STDERR "hit score line\n" if 2 <= $self->{'_debug'};
-      $hit->score($1);
-      $state = $SIZE;
+      $hit->score($1) if ref($hit);
+      $state = $HITS;
       }
 
-    elsif ($state eq $SIZE && m=\(Size\s([0-9.KM]+)\)=)
+    elsif ($state eq $HITS && m=\(Size\s([0-9.KM]+)\)=)
       {
       print STDERR "hit size line\n" if 2 <= $self->{'_debug'};
       my $size = $1;
       $size =~ s/K/*1024/;
       $size =~ s/M/*1024*1024/;
-      $hit->size(eval $size);
-      $state = $DATE;
+      $hit->size(eval $size) if ref($hit);
+      $state = $HITS;
       }
 
-    elsif ($state eq $DATE && m=Document\sDate:(&nbsp;)?\s*(\d+\s+[a-zA-Z]+\s+\d+)=)
+    elsif ($state eq $HITS && m=Date:(&nbsp;)?\s*(\d+\s+[A-Z][a-z]+\s+\d+)=)
       {
       print STDERR "hit change_date line\n" if 2 <= $self->{'_debug'};
       # Actual line of input is:
       # Document&nbsp;date: 22 Oct 1996 </font><br>
-      $hit->change_date($2);
+      $hit->change_date($2) if ref($hit);
       $state = $HITS;
       }
-    elsif ($state eq $DATE && m=^(<b>)?([a-zA-Z]+\s+\d+\s+[a-zA-Z]+\s+[\d:]+)(</b>)?=)
+    elsif ($state eq $HITS && m=^(<b>)?([a-zA-Z]+\s+\d+\s+[a-zA-Z]+\s+[\d:]+)(</b>)?=)
       {
       print STDERR "hit news date line\n" if 2 <= $self->{'_debug'};
       # Actual lines of input include:
       # Document&nbsp;date: 22 Oct 1996 </font><br>
       # Wed 19 Aug 13:38
-      $hit->change_date($2);
+      $hit->change_date($2) if ref($hit);
       $state = $HITS;
       }
 
@@ -400,11 +406,6 @@ sub native_retrieve_some
       }
     } # foreach line of query results HTML page
 
-  if ($state ne $TRAILER)
-    {
-    # End, no other pages (missed some tag somewhere along the line?)
-    $self->{_next_url} = undef;
-    }
   if (defined($hit)) 
     {
     push(@{$self->{cache}}, $hit);
