@@ -1,9 +1,8 @@
 #!/usr/local/bin/perl -w
 
-#
 # News.pm
 # Copyright (c) 1998 by Martin Thurn
-# $Id: News.pm,v 1.7 1998/05/28 04:05:52 johnh Exp $
+# $Id: News.pm,v 1.8 1998/08/21 00:03:57 johnh Exp $
 
 
 package WWW::Search::Infoseek::News;
@@ -14,7 +13,7 @@ WWW::Search::Infoseek::News - class for Infoseek News searching
 
 
 =head1 SYNOPSIS
-
+    
     require WWW::Search;
     $search = new WWW::Search('Infoseek::News');
 
@@ -35,14 +34,14 @@ be done through WWW::Search objects.
 This module adheres to the WWW::Search test harness.  Test cases are:
 
   'mrfglbqnx NoSuchWord' --> no hits
-  'Star Wars'            --> 13 hits on one page
-  'Hawaii'               --> 54 hits on two pages
+  'Star Wars'            -->  5 hits on one page
+  'Hawaii'               --> 62 hits on three pages
 
 
 =head1 AUTHOR
 
 C<WWW::Search::Infoseek::News> 
-was written by Martin Thurn <mthurn@irnet.rest.tasc.com> 
+was written by Martin Thurn <MartinThurn@iname.com> 
 
 
 =cut
@@ -53,6 +52,8 @@ require Exporter;
 @EXPORT = qw();
 @EXPORT_OK = qw();
 @ISA = qw(WWW::Search::Infoseek Exporter);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
+
 use WWW::Search::Infoseek;
 
 # private
