@@ -1,9 +1,8 @@
 #!/usr/local/bin/perl -w
 
-#
 # Web.pm
 # Copyright (c) 1998 by Martin Thurn
-# $Id: Web.pm,v 1.6 1998/05/28 04:05:53 johnh Exp $
+# $Id: Web.pm,v 1.7 1998/08/21 00:03:57 johnh Exp $
 
 package WWW::Search::Infoseek::Web;
 
@@ -13,9 +12,13 @@ WWW::Search::Infoseek::Web - class for Infoseek Web searching
 
 
 =head1 SYNOPSIS
-
-    require WWW::Search;
-    $search = new WWW::Search('Infoseek::Web');
+    
+  use WWW::Search;
+  my $oSearch = new WWW::Search('Infoseek::Web');
+  my $sQuery = WWW::Search::escape_query("+sushi restaurant +Columbus Ohio");
+  $oSearch->native_query($sQuery);
+  while (my $oResult = $oSearch->next_result())
+    { print $oResult->url, "\n"; }
 
 
 =head1 DESCRIPTION
@@ -31,17 +34,17 @@ be done through WWW::Search objects.
 
 =head1 TESTING
 
-This module adheres to the WWW::Search test harness.  Test cases are:
+This module adheres to the WWW::Search test harness.  
 
-  'mrfglbqnx NoSuchWord' --> no hits
-  'Martin Thurn'         --> 24 hits on one page
-  '+Greedo +collector'   --> 63 hits on two pages
+  'mrfglbqnx NoSuchWord'       --> no hits
+  'Martin Thurn AND Star Wars' --> 11 hits on one page
+  'Greedo AND collectible'     --> 38 hits on two pages
 
 
 =head1 AUTHOR
 
 C<WWW::Search::Infoseek::Web> 
-was written by Martin Thurn <mthurn@irnet.rest.tasc.com> 
+was written by Martin Thurn <MartinThurn@iname.com> 
 
 
 =cut
@@ -52,6 +55,8 @@ require Exporter;
 @EXPORT = qw();
 @EXPORT_OK = qw();
 @ISA = qw(WWW::Search::Infoseek Exporter);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+
 use WWW::Search::Infoseek;
 
 # Infoseek.pm does all the work by default!
